fairly.dataset package
======================

Submodules
----------

fairly.dataset.local module
---------------------------

.. automodule:: fairly.dataset.local
   :members:
   :undoc-members:
   :show-inheritance:

fairly.dataset.remote module
----------------------------

.. automodule:: fairly.dataset.remote
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fairly.dataset
   :members:
   :undoc-members:
   :show-inheritance:
